@@ -6,19 +6,23 @@
 */
 
 #include "gui/scanprogressdialog.h"
-
-#include <QCloseEvent>
-
 #include <KLocalizedString>
+#include <QCloseEvent>
+#include <QProgressBar>
 
 ScanProgressDialog::ScanProgressDialog(QWidget* parent) :
     QProgressDialog(parent)
 {
-    setWindowTitle(xi18nc("@title:window", "Scanning devices..."));
+    setWindowTitle(xi18nc("@title:window", "Scanning Devices…"));
     setMinimumWidth(280);
     setMinimumDuration(150);
     setValue(0);
     setAttribute(Qt::WA_ShowModal, true);
+
+    QProgressBar* progressBar = findProgressBar();
+    if (progressBar) {
+        progressBar->setFormat(i18nc("%p is the percent value, % is the percent sign", "%p%"));
+    }
 }
 
 void ScanProgressDialog::closeEvent(QCloseEvent* e)
@@ -29,7 +33,7 @@ void ScanProgressDialog::closeEvent(QCloseEvent* e)
 void ScanProgressDialog::setDeviceName(const QString& device)
 {
     if (device.isEmpty()) {
-        setLabelText(xi18nc("@label", "Scanning..."));
+        setLabelText(xi18nc("@label", "Scanning…"));
     } else {
         setLabelText(xi18nc("@label", "Scanning device: <filename>%1</filename>", device));
     }
@@ -38,6 +42,11 @@ void ScanProgressDialog::setDeviceName(const QString& device)
 void ScanProgressDialog::showEvent(QShowEvent* e)
 {
     setCancelButton(nullptr);
-
     QProgressDialog::showEvent(e);
 }
+
+QProgressBar* ScanProgressDialog::findProgressBar()
+{
+    auto children = findChildren<QProgressBar*>();
+    return children.isEmpty() ? nullptr : children.first();
+}
